@@ -1,5 +1,5 @@
 /*
-Copyright 2020 The Knative Authors
+Copyright 2019 The Knative Authors
 
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
@@ -20,19 +20,18 @@ import (
 	"context"
 	"testing"
 
-	_ "knative.dev/eventing-operator/pkg/client/injection/client/fake"
 	_ "knative.dev/pkg/client/injection/kube/client/fake"
 	_ "knative.dev/pkg/injection/clients/dynamicclient/fake"
+	_ "knative.dev/operator/pkg/client/injection/client/fake"
 
 	"k8s.io/client-go/rest"
 	"knative.dev/pkg/configmap"
 	"knative.dev/pkg/injection"
-	_ "knative.dev/pkg/system/testing"
 )
 
 var reconcilerName = "test-reconciler"
 
-func TestNew(t *testing.T) {
+func TestNewBase(t *testing.T) {
 	ctx, cancel := context.WithCancel(context.Background())
 	defer cancel()
 
@@ -49,4 +48,7 @@ func TestNew(t *testing.T) {
 	if r.Recorder == nil {
 		t.Fatal("Expected NewBase to add a Recorder")
 	}
+	if r.StatsReporter == nil {
+		t.Fatal("Expected NewBase to add a StatsReporter")
+	}
 }
